//Конкатенация индексов
function [pathToFile]=GenerateFileByTemplate(pathToFileTemplate,..//Путь к шаблону файлов
                                             fileTemplateName,..//Имя шаблона задач файлов
                                             pathToFile,..//Путь к сгенерированному файлу
                                             fileName,..//Имя сгенерированного файла
                                             positionIncludindDatas,..//Позиция включаемых данных
                                             includedStrs..//Включаемые строки
                                             )
    //Проверяем аргументы
    if argn(2) < 6 then
        error('The function GenerateFileByTemplate takes 6 arguments');
    end
    
    //Проверяем корректность аргументов
    if (type(pathToFileTemplate) ~= 10) ||..
       (size(pathToFileTemplate,"*") > 1) then
        error("The argument pathToFileTemplate of function GenerateFileByTemplate must be scalar string");
    end
    if (type(fileTemplateName) ~= 10) ||..
       (size(fileTemplateName,"*") > 1) then
        error("The argument fileTemplateName of function GenerateFileByTemplate must be scalar string");
    end
    if (type(pathToFile) ~= 10) ||..
       (size(pathToFile,"*") > 1) then
        error("The argument pathToFile of function GenerateFileByTemplate must be scalar string");
    end
    if type(fileName) ~= 10 then
        error("The argument fileName of function GenerateFileByTemplate must be matrix of string");
    end
    if (type(positionIncludindDatas) ~= 10) ||..
       (size(positionIncludindDatas,"*") > 1) then
        error("The argument positionIncludindDatas of function GenerateIndexedTasks must be ""b"" or ""u""");
    end
    if type(includedStrs) ~= 10 then
        error("The argument includedStrs of function GenerateIndexedTasks must be matrix of string");
    end
    
    //Генерируем файл
    fullFileTemplateName = fullfile(pathToFileTemplate,fileTemplateName);//Полное имя файла шаблона
    strsTaskTemplate = mgetl(fullFileTemplateName);//Считываем содержимое шаблона
    nIncludesStrs = size(includedStrs)(1);//Число сохраняемых строк
    fullFileName = fullfile(pathToFile,fileName);//Полное имя файла
    for indIncludedStrs=1:nIncludesStrs
        //Приводим к столбцу строк
        curIncludedStrs = matrix(includedStrs(indIncludedStrs,:),-1,1);
        
        //Добавляем к считанным строкам
        if positionIncludindDatas == "b" then
            curIncludedStrs = [strsTaskTemplate;curIncludedStrs];
        elseif positionIncludindDatas == "u" then
            curIncludedStrs = [curIncludedStrs;strsTaskTemplate];
        else
            error("The argument positionIncludindDatas of function GenerateIndexedTasks must be ""b"" or ""u""");
        end
        
        //Сохраняем в файл
        mputl(curIncludedStrs,fullFileName(indIncludedStrs));//Сохраняем в файл
    end
endfunction
