//Конкатенация индексов
function [indexedTasksNames,..//Индексированные имена задач
          indexMatrix]=GenerateIndexedTasks(pathToTasksTemplate,..//Путь к шаблону задач
                                            taskTemplateName,..//Имя шаблона задач
                                            pathToTasks,..//Путь к сгенерированным задачам
                                            beginPartName,..//Начальная часть имени файла
                                            endPartName,..//Конечная часть имени файла
                                            indexSepName,..//Ращзделитель индексов
                                            inputIndexedValuesNames,..//Имена индексированных входных величин
                                            minIndexes,..//Минимальные значения индексов
                                            maxIndexes,..//Максимальные значения индексов
                                            stepIndexes,..//Шаги индексов
                                            elementsIndexes,..//Элементы в качестве индексов
                                            grid)
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 8 then
        error('The function GenerateIndexedTasks takes 8, 9, 10, 11 or 12 arguments');
    end
    select nArg
    case 8 then
        maxIndexes = minIndexes;
        minIndexes = ones(maxIndexes);//По умолчанию минимумы берем единицы
        stepIndexes = ones(maxIndexes);//По умолчанию шаг берем единицы
        elementsIndexes = [];//По умолчанию берем пустыми
        grid = %t;//По умолчанию делаем сетку
    case 9 then
        if type(maxIndexes) == 4 then
            grid = maxIndexes;
            maxIndexes = minIndexes;
            minIndexes = ones(maxIndexes);//По умолчанию минимумы берем единицы
        else
            grid = %t;//По умолчанию делаем сетку
        end
        stepIndexes = ones(maxIndexes);//По умолчанию шаг берем единицы
        elementsIndexes = [];//По умолчанию берем пустыми
    case 10 then
        if type(stepIndexes) == 4 then
            grid = stepIndexes;
            stepIndexes = ones(maxIndexes);//По умолчанию шаг берем единицы
        else
            grid = %t;//По умолчанию делаем сетку
        end
        elementsIndexes = [];//По умолчанию берем пустыми
    case 11 then
        if type(elementsIndexes) == 4 then
            grid = elementsIndexes;
            elementsIndexes = [];//По умолчанию берем пустыми
        else
            grid = %t;//По умолчанию делаем сетку
        end
    end
    
    //Проверяем корректность аргументов
    if (type(pathToTasksTemplate) ~= 10) ||..
       (size(pathToTasksTemplate,"*") > 1) then
        error("The argument pathToTasksTemplate of function GenerateIndexedTasks must be scalar string");
    end
    if (type(taskTemplateName) ~= 10) ||..
       (size(taskTemplateName,"*") > 1) then
        error("The argument taskTemplateName of function GenerateIndexedTasks must be scalar string");
    end
    if (type(pathToTasks) ~= 10) ||..
       (size(pathToTasks,"*") > 1) then
        error("The argument pathToTasks of function GenerateIndexedTasks must be scalar string");
    end
    if type(inputIndexedValuesNames) ~= 10 then
        error("The argument inputIndexedValuesNames of function GenerateIndexedTasks must be matrix of string");
    end
    
    //Формируем имена файов задач
    extTasks = fileext(taskTemplateName);//Расширение файлов задач
    [indexedTasksNames,..
     indexMatrix]=FileNamesIndexesRange(beginPartName,endPartName,..
                                        indexSepName,extTasks,..
                                        minIndexes,maxIndexes,stepIndexes,..
                                        elementsIndexes,grid);//Формируем имена файлов задач
    
    //Проверяем корректность аргументов
    if size(inputIndexedValuesNames,"*") ~= size(maxIndexes,"*") then
        error("The number of indexed values names and indexes maximum values must be equality");
    end
    
    //Формируем записываемыес троки
    nGeneratingTasks = size(indexedTasksNames,"*");//Число генерируемых задач
    inputIndexedValuesNames = repmat(inputIndexedValuesNames,[nGeneratingTasks,1]);//Размножаем заголовки
    strInputIndexedValues = inputIndexedValuesNames + " = " + string(indexMatrix) + ";";//Записываемые строки
    
    //Генерируем задачи
    GenerateFileByTemplate(pathToTasksTemplate,..//Путь к шаблону файлов
                           taskTemplateName,..//Имя шаблона задач файлов
                           pathToTasks,..//Путь к сгенерированному файлу
                           indexedTasksNames,..//Имя сгенерированного файла
                           "u",..//Позиция включаемых данных
                           strInputIndexedValues..//Включаемые строки
                           );
endfunction
